export class ConnectionPool {
    /**
     * @param {NetworkRequest[]} records
     * @param {Required<SimulationOptions>} options
     */
    constructor(records: NetworkRequest[], options: Required<SimulationOptions>);
    _options: Required<import("../../../../types/internal/lantern.js").Lantern.Simulation.Options>;
    _records: import("../../../../types/internal/lantern.js").Lantern.NetworkRequest<any>[];
    /** @type {Map<string, TcpConnection[]>} */
    _connectionsByOrigin: Map<string, TcpConnection[]>;
    /** @type {Map<NetworkRequest, TcpConnection>} */
    _connectionsByRecord: Map<NetworkRequest, TcpConnection>;
    _connectionsInUse: Set<any>;
    _connectionReusedByRequestId: Map<string, boolean>;
    /**
     * @return {TcpConnection[]}
     */
    connectionsInUse(): TcpConnection[];
    _initializeConnections(): void;
    /**
     * @param {Array<TcpConnection>} connections
     * @param {{ignoreConnectionReused?: boolean, observedConnectionWasReused: boolean}} options
     */
    _findAvailableConnectionWithLargestCongestionWindow(connections: Array<TcpConnection>, options: {
        ignoreConnectionReused?: boolean | undefined;
        observedConnectionWasReused: boolean;
    }): TcpConnection | null;
    /**
     * This method finds an available connection to the origin specified by the network record or null
     * if no connection was available. If returned, connection will not be available for other network
     * records until release is called.
     *
     * If ignoreConnectionReused is true, acquire will consider all connections not in use as available.
     * Otherwise, only connections that have matching "warmth" are considered available.
     *
     * @param {NetworkRequest} record
     * @param {{ignoreConnectionReused?: boolean}} options
     * @return {?TcpConnection}
     */
    acquire(record: NetworkRequest, options?: {
        ignoreConnectionReused?: boolean;
    }): TcpConnection | null;
    /**
     * Return the connection currently being used to fetch a record. If no connection
     * currently being used for this record, an error will be thrown.
     *
     * @param {NetworkRequest} record
     * @return {TcpConnection}
     */
    acquireActiveConnectionFromRecord(record: NetworkRequest): TcpConnection;
    /**
     * @param {NetworkRequest} record
     */
    release(record: NetworkRequest): void;
}
export type NetworkRequest = import('../../../../types/internal/lantern.js').Lantern.NetworkRequest;
export type SimulationOptions = import('../../../../types/internal/lantern.js').Lantern.Simulation.Options;
import { TcpConnection } from './tcp-connection.js';
//# sourceMappingURL=connection-pool.d.ts.map